@@ -1,10 +1,12 @@
-package Exporter::Easiest;
-$Exporter::Easiest::VERSION = '0.16_01';
-use 5.006;
+# $Header: /home/fergal/my/cvs/Exporter-Easy/lib/Exporter/Easiest.pm,v 1.1 2003/02/11 23:55:07 fergal Exp $
+# Be lean.
 use strict;
-use warnings;
-
 no strict 'refs';
+
+package Exporter::Easiest;
+
+require 5.006;
+
 require Exporter::Easy;
 
 sub import
@@ -13,9 +15,9 @@ sub import
 
 	my $callpkg = caller(0);
 
-	@_ = ($callpkg, parse_spec(@_));
+	my @real_spec = parse_spec(@_);
 
-	goto &Exporter::Easy::set_export_vars;
+	&Exporter::Easy::set_export_vars($callpkg, @real_spec);
 }
 
 sub parse_spec
@@ -32,33 +34,20 @@ sub parse_spec
 	{
 		my $new_key = shift @spec;
 		my $arrow = shift @spec;
-		$arrow = "" unless defined($arrow);
-		die "Expected '=>' not '$arrow' after $new_key" unless ($arrow eq '=>');
+		die "Expected => not '$arrow' after $new_key" unless ($arrow eq '=>');
+
 
 		if ($new_key =~ s/^://)
 		{
 			# if the new key starts with a : then it and the following list are
-			# pushed onto the TAGS entry
+			# pushed onto the previous keys's entry
 
-			push(@{$spec{TAGS}}, $new_key, suck_list(\@spec));
+			push(@{$spec{$key}}, $new_key, suck_list(\@spec));
 		}
 		else
 		{
 			$key = $new_key;
-
-			# VARS and ISA should aren't necessarily a list
-
-			if(
-				($key =~ /^(VARS|ISA)$/ and $spec[0] =~ /^\d+$/) or
-				($key eq 'ALL')
-			)
-			{
-				$spec{$key} = shift @spec;
-			}
-			else
-			{
-				$spec{$key} = suck_list(\@spec);
-			}
+			$spec{$key} = suck_list(\@spec);
 		}
 	}
 
@@ -101,10 +90,10 @@ In module YourModule.pm:
 
   package YourModule;
   use Exporter::Easiest q(
-    EXPORT => :tag1
     OK => munge frobnicate
-   	:tag1 => a b c 
-   	:tag2 => :tag1 d e f
+    TAGS =>
+    	:tag1 => a b c 
+    	:tag2 => :tag1 d e f
     FAIL => f g h
   );
 
@@ -118,23 +107,16 @@ In other files which wish to use YourModule:
 The Exporter::Easiest module is a wrapper around Exporter::Easy. It allows
 you to pass the arguments into Exporter::Easy without all those tiresome []s
 and qw()s. You pass arguments in as a string or an array of strings. You no
-longer need to bracket lists or take references. If want, you can also leave
-out the TAGS key and just put tag definitions along with the other keys.
+longer need to brack things or take references.
 
-The important thing to remember is that tags should be preceded by ':'
-everywhere, including to the left of the '=>', otherwise it'll get confused.
-And don't worry I haven't done something horribly pythonesque, whitespace is
-not significant, all the parsing logic revolves around the use of ':'s and
-'=>'s
+The important thing to remember is that tags should be preceded by :
+everywhere, including to the left of the =>, otherwise it'll get confused.
+Don't worry I haven't done something horribly pythonesque, whitespace is not
+significant.
 
 =head1 SEE ALSO
 
-For the real details on exporting symbols see L<Exporter>
-and L<Exporter::Easy>.
-
-=head1 REPOSITORY
-
-L<https://github.com/neilbowers/Exporter-Easy>
+For the real details on exporting symbols see Exporter and Exporter::Easy
 
 =head1 AUTHOR
 
